﻿using Android.App;
using Android.Widget;
using Android.OS;
using Android.Views;

using Com.Extbcr.Scannersdk;
using System;
using System.Diagnostics;
using Android.Graphics;
using Android.Content.PM;
using System.Collections.Generic;

namespace H28SDKTestApp
{
    [Activity(Label = "H28SDKTestApp", MainLauncher = true, Icon = "@mipmap/icon", ScreenOrientation = ScreenOrientation.Portrait)]
    public class MainActivity : Activity //, Com.Extbcr.Scannersdk.IEventListener
    {
        Button buttonScan;
        Button buttonTrigger;
        EditText showScanResult;
        TextView scannerStatus;

        public bool triggerMode = false;
        public bool bcrServerConnect = false;
        private BarcodeManager barcodeManager;
        public BarcodeScannerEvents bcrScannerEvents;
        

        protected override void OnCreate(Bundle savedInstanceState)
        {
            base.OnCreate(savedInstanceState);

            // Set our view from the "main" layout resource
            SetContentView(Resource.Layout.Main);

            buttonScan = FindViewById<Button>(Resource.Id.buttonScan);
            buttonScan.Touch += ButtonScan_Touch;

            buttonTrigger = FindViewById<Button>(Resource.Id.buttonTrigger);
            buttonTrigger.Touch += ButtonTrigger_Touch;

            scannerStatus = FindViewById<TextView>(Resource.Id.textScannerStatus);
            scannerStatus.Text = "Ready to Scan";

            showScanResult = FindViewById<EditText>(Resource.Id.editBarcodeResult);
            showScanResult.Hint = "Press the TRIGGER or SCAN button to acquire a barcode";
            showScanResult.Focusable = false;
            showScanResult.SetCursorVisible(false);
        }

        void InitScanner()
        {
            barcodeManager = new BarcodeManager(this);
            barcodeManager.Init();

            bcrScannerEvents = new BarcodeScannerEvents();
            bcrScannerEvents.OnTimeoutEvent += _bcrScannerEvents_OnTimeoutEvent;
            bcrScannerEvents.OnConnectEvent += _bcrScannerEvents_OnConnectEvent;
            bcrScannerEvents.OnDisconnectEvent += _bcrScannerEvents_OnDisconnectEvent;
            bcrScannerEvents.OnStartEvent += _bcrScannerEvents_OnStartEvent;
            bcrScannerEvents.OnStopEvent += _bcrScannerEvents_OnStopEvent;
            bcrScannerEvents.OnReadDataEvent += _bcrScannerEvents_OnReadDataEvent;

            barcodeManager.AddListener(bcrScannerEvents);
        }

        override protected void OnResume() 
        {
            base.OnResume();

            VolumeControlStream = Android.Media.Stream.Music;
            triggerMode = false;
            buttonTrigger.Text = "TRIGGER";
            showScanResult.Hint = "Press the TRIGGER or SCAN button to acquire a barcode";
            scannerStatus.Text = "Ready to Scan";
            scannerStatus.SetTextColor(Color.White);

            InitScanner();
        }

        protected override void OnPause()
        {
            base.OnPause();
            try
            {
                if (bcrServerConnect)
                {
                    barcodeManager.StopDecode();
                    barcodeManager.StopTriger();
                }
                barcodeManager.RemoveListener();
                barcodeManager.Deinit();
                barcodeManager = null;
                bcrScannerEvents = null;
            }
            catch {}
        }

        private void _bcrScannerEvents_OnTimeoutEvent(object sender, EventArgs e)
        {
            System.Diagnostics.Trace.Write("OnTimeoutEvent\r\n");
            scannerStatus.SetTextColor(Color.Cyan);
            scannerStatus.Text = "Timeout";

        }

        private void _bcrScannerEvents_OnConnectEvent(object sender, EventArgs e)
        {
            System.Diagnostics.Trace.Write("OnConnectEvent\r\n");
            bcrServerConnect = true;

            AllSettings allsettings = new AllSettings();
            allsettings.SetValue(PropertyID.ChinesePostMatrix2of5Enable, 1);
            allsettings.SetValue(PropertyID.KoreanPostalAuthorityEnable, 1);
            allsettings.SetValue(PropertyID.NetherlandsKixCodeEnable, 1);
            allsettings.SetValue(PropertyID.PostnetEnable, 1);
            allsettings.SetValue(PropertyID.TelepenEnable, 1);
            allsettings.SetValue(PropertyID.MsiPlesseyEnable, 1);
            allsettings.SetValue(PropertyID.UkPlesseyEnable, 1);
            allsettings.SetValue(PropertyID.Matrix2of5Enable, 1);

        }

        private void _bcrScannerEvents_OnDisconnectEvent(object sender, EventArgs e)
        {
            System.Diagnostics.Trace.Write("OnDisconnectEvent\r\n");

            bcrServerConnect = false;
        }

        private void _bcrScannerEvents_OnStartEvent(object sender, EventArgs e)
        {
            System.Diagnostics.Trace.Write("OnStartEvent\r\n");
            scannerStatus.SetTextColor(Color.Red);
            scannerStatus.Text = "Scanning...";
        }

        private void _bcrScannerEvents_OnStopEvent(object sender, EventArgs e)
        {
            System.Diagnostics.Trace.Write("OnStopEvent\r\n");
            scannerStatus.SetTextColor(Color.White);
            scannerStatus.Text = "Ready to Scan";
        }

        private void _bcrScannerEvents_OnReadDataEvent(object sender, EventArgs bcrData)
        {
            System.Diagnostics.Trace.Write("OnReadDataEvent\r\n");

            scannerStatus.SetTextColor(Color.Green);
            scannerStatus.Text = "Success";

            ReadDataEventArgs args = (ReadDataEventArgs)bcrData;
            string strcodeId = "Code ID: " + CodeID.CodeIDtoString(args.P0.CodeID) + "\n";
            string strBcr = "Result: " + args.P0.Text;
            if (strBcr != null)
            {
                if (strBcr.Length > 310)
                {
                    strBcr = strBcr.Substring(0, 310);
                    strBcr += "[...]";
                }
                showScanResult.Text = strcodeId + strBcr;
            }
 
        }


        private void ButtonScan_Touch(object sender, View.TouchEventArgs e)
        {
            if (e.Event.Action == MotionEventActions.Down)
            {
                try
                {
                    if (triggerMode)
                    {
                        triggerMode = false;
                        buttonTrigger.Text = "TRIGGER";
                    }

                        buttonScan.Pressed = true;
                    if (bcrServerConnect)
                        barcodeManager.StartDecode();
                       
                }
                catch { }

            }
            if (e.Event.Action == MotionEventActions.Cancel || e.Event.Action == MotionEventActions.Up)
            {
                try
                {
                    buttonScan.Pressed = false;
                    if (bcrServerConnect)
                        barcodeManager.StopDecode();
                }
                catch { }
            }
        }

        private void ButtonTrigger_Touch(object sender, Android.Views.View.TouchEventArgs e)
        {
            if (e.Event.Action == MotionEventActions.Down)
            {
                try
                {
                    buttonTrigger.Pressed = true;
                    triggerMode ^= true;
                    if (triggerMode)
                    {
                        buttonTrigger.Text = "STOP";
                        showScanResult.Text = "";
                        if (bcrServerConnect)
                            barcodeManager.StartTriger();
                    }
                    else
                    {
                        buttonTrigger.Text = "TRIGGER";
                        if (bcrServerConnect)
                            barcodeManager.StopTriger();

                    }
                }
                catch { }
            }
            if (e.Event.Action == MotionEventActions.Cancel || e.Event.Action == MotionEventActions.Up)
            {
                try
                {
                    buttonTrigger.Pressed = false;
                }
                catch { }
            }

        }

 
    }
}

