package com.opticon.scannersample;

import com.extbcr.scannersdk.BarcodeManager;
import com.extbcr.scannersdk.EventListener;
import com.extbcr.scannersdk.CodeID;
import com.extbcr.scannersdk.BarcodeData;

import android.os.Bundle;
import android.app.Activity;
import android.graphics.Color;
import android.view.KeyEvent;
import android.view.MotionEvent;
import android.view.View;
import android.view.View.OnTouchListener;
import android.view.Window;
import android.view.WindowManager;
import android.widget.Button;
import android.widget.EditText;
import android.widget.TextView;
import android.util.Log;
import android.media.AudioManager;
import android.os.Handler;

import android.content.res.Configuration;

public class MainActivity extends Activity {
	private static final String TAG = "ScannerSDK-MainActivity";

	private EditText showScanResult;
	private TextView status;
	private Button mScan;
	private Button mTrigger;
	private int statusTextColor;
	private BarcodeManager mBarcodeManager;
	private EventListener mEventListener;

	private boolean ignoreStop = false;
	int i=0;
	private boolean trigermode = false;
	private boolean serverconnect = false;
	Handler mHandler;
	Runnable mRunnable;

	@Override
	protected void onCreate(Bundle savedInstanceState) {
		Log.e(TAG, "onCreate: " + Thread.currentThread().getId());
		super.onCreate(savedInstanceState);
		Window window = getWindow();
		window.addFlags(WindowManager.LayoutParams.FLAG_KEEP_SCREEN_ON);
		setContentView(R.layout.activity_main);
		setupView();
		//initScan();
	}

	private void initScan() {
		Log.e(TAG, "initScan: XXX");
		mBarcodeManager = new BarcodeManager(this);
		mBarcodeManager.init();

		mEventListener = new EventListener() {

			@Override
			public void onReadData(BarcodeData result) {
				Log.e(TAG, "onReadData " + result.getText() + ", codeid is" + result.getCodeID());

				status.setTextColor(Color.GREEN);
				status.setText("Success");
				showScanResult.setText("");
				showScanResult.append("CodeID: " + CodeID.CodeIDtoString(result.getCodeID()) + "\n");
				String string = result.getText();
				if( string!= null) {
					if(string.length() > 200) {
						string = string.substring(0, 200);
						string = string + "[...]";
					}
					showScanResult.append("Result: " + string+ "\n");
				}
				ignoreStop = true;

			}

			@Override
			public void onTimeout() {
				Log.e(TAG, "onTimeout");

				status.setTextColor(Color.CYAN);
				status.setText("Timeout");
				ignoreStop = true;
			}

			@Override
			public void onConnect(){
				Log.e(TAG, "onConnect");
				serverconnect = true;

			}

			@Override
			public void onDisconnect(){
				Log.e(TAG, "onDisconnect");
				serverconnect = false;
			}

			@Override
			public void onStart(){
				Log.e(TAG, "onStart");
				status.setTextColor(Color.RED);
				status.setText("Scanning");
			}

			@Override
			public void onStop(){
				Log.e(TAG, "onStop");
				status.setTextColor(Color.WHITE);
				status.setText("Ready to Scan");
			}
		};

		mBarcodeManager.addListener(mEventListener);
	}

	private void setupView() {
		showScanResult = (EditText) findViewById(R.id.scan_result);
		showScanResult.setKeyListener(null);

		status = (TextView) findViewById(R.id.wcccamera_title);
		statusTextColor = status.getCurrentTextColor();

		mScan = (Button) findViewById(R.id.scan);
		mScan.setOnTouchListener(new OnTouchListener() {

			@Override
			public boolean onTouch(View v, MotionEvent event) {
				if(event.getAction() == MotionEvent.ACTION_DOWN) {
					try {
						mScan.setPressed(true);
						if(serverconnect)
							mBarcodeManager.startDecode();
					} catch (Exception e) {

					}
				} else if (event.getAction() == MotionEvent.ACTION_UP) {
					try {
						mScan.setPressed(false);
						if(serverconnect)
							mBarcodeManager.stopDecode();
					} catch (Exception e) {
					}
				}
				return true;
			}
		}
				);

		mTrigger = (Button) findViewById(R.id.trigger);
		//mTrigger.setVisibility(View.GONE);
		mTrigger.setOnTouchListener(new OnTouchListener() {

			@Override
			public boolean onTouch(View v, MotionEvent event) {
				if(event.getAction() == MotionEvent.ACTION_DOWN) {
					try {
						mTrigger.setPressed(true);
						if(trigermode){
							mTrigger.setText("TRIGGER");
							trigermode = false;
							if(serverconnect)
								mBarcodeManager.stopTriger();
						}
						else {
							mTrigger.setText("STOP");
							showScanResult.setText("");
							trigermode = true;
							if(serverconnect)
								mBarcodeManager.startTriger();
						}
					} catch (Exception e) {

					}
				} else if (event.getAction() == MotionEvent.ACTION_UP) {
					try {
						mTrigger.setPressed(false);
					} catch (Exception e) {
					}
				}
				return true;
			}
		}
				);

	}

	@Override
	protected void onDestroy() {
		super.onDestroy();
	}

	@Override
	protected void onPause() {
		super.onPause();
		try {
			if(serverconnect) mBarcodeManager.stopDecode();
			if(trigermode) { Log.e(TAG, "onPause trigermode is true, stopTriger");  mBarcodeManager.stopTriger(); }
			mBarcodeManager.removeListener();
			mBarcodeManager.deinit();
		} catch (Exception e) {
		}
	}

	protected void initParameter() {
		mTrigger.setText("TRIGGER");
		status.setText("Ready to Scan");
		status.setTextColor(Color.WHITE);
		trigermode = false;
	}

	@Override
	protected void onResume() {
		super.onResume();
		setVolumeControlStream(AudioManager.STREAM_MUSIC);
		showScanResult.setText(getResources().getText(R.string.scanner_hint));
		initParameter();
		initScan();
	}

	@Override
	protected void onStart() {
		super.onStart();
	}

	@Override
	public boolean onKeyDown(int keyCode, KeyEvent event) {
		return super.onKeyDown(keyCode, event);
	}

	@Override
	public void onConfigurationChanged(Configuration newConfig) {
		Log.e(TAG, "onConfigurationChanged");
		super.onConfigurationChanged(newConfig);
	}
}
